body.et_non_fixed_nav.et_transparent_nav.et_boxed_layout #page-container,body.et_fixed_nav.et_boxed_layout #page-container{padding-top:80px}body.et_fixed_nav.et_boxed_layout.et-tb #page-container,body.et_fixed_nav.et_boxed_layout.et-tb-has-header #page-container{padding-top:0 !important}.et_boxed_layout #page-container{-webkit-box-shadow:0 0 10px 0 rgba(0,0,0,0.2);box-shadow:0 0 10px 0 rgba(0,0,0,0.2)}.et_boxed_layout #page-container,.et_boxed_layout.et_non_fixed_nav.et_transparent_nav #page-container #top-header,.et_non_fixed_nav.et_transparent_nav.et_boxed_layout #page-container #main-header,.et_fixed_nav.et_boxed_layout #page-container #top-header,.et_fixed_nav.et_boxed_layout #page-container #main-header,.et_boxed_layout #page-container .container,.et_boxed_layout #page-container .et_pb_row,.et_boxed_layout.et_pb_pagebuilder_layout.single.et_full_width_page #page-container .et_pb_row,.et_boxed_layout.et_pb_pagebuilder_layout.single.et_full_width_portfolio_page #page-container .et_pb_row,.et_boxed_layout.et_pb_pagebuilder_layout.single #page-container .et_pb_row{width:90%;max-width:1200px;margin:auto}.et_boxed_layout.et_vertical_nav #page-container{max-width:1425px}.et_boxed_layout.et_vertical_nav #page-container #top-header{width:auto;max-width:none}.et_boxed_layout.et_vertical_right.et_vertical_fixed #main-header{opacity:0}.et_boxed_layout.et_vertical_right.et_vertical_fixed #page-container #main-header.et_vertical_menu_set{opacity:1;-webkit-transition:opacity 0.4s ease-in-out;transition:opacity 0.4s ease-in-out}

